==> CGAL-5.6.1-doc_html.tar.xz: doc_html/HalfedgeDS/group__PkgHalfedgeDS__Decorators.js <==
var group__PkgHalfedgeDS__Decorators =
[
    [ "HalfedgeDS_const_decorator", "classCGAL_1_1HalfedgeDS__const__decorator.html", [
      [ "HalfedgeDS_const_decorator", "classCGAL_1_1HalfedgeDS__const__decorator.html#ad5b6cdd3e8928c725e3c76b75503ca87", null ],
      [ "is_valid", "classCGAL_1_1HalfedgeDS__const__decorator.html#a20c407cf3b51a5405de75d6ecac54bb8", null ],
      [ "normalized_border_is_valid", "classCGAL_1_1HalfedgeDS__const__decorator.html#a2d34287e8e79a93a0c8aede41e24a33e", null ]
    ] ],
    [ "HalfedgeDS_decorator", "classCGAL_1_1HalfedgeDS__decorator.html", [
      [ "HalfedgeDS_decorator", "classCGAL_1_1HalfedgeDS__decorator.html#adbca9056aa23e29f8c5794577478aa12", null ],
      [ "add_face_to_border", "classCGAL_1_1HalfedgeDS__decorator.html#a03103d1282804931094481b8351e3416", null ],
      [ "add_face_to_border", "classCGAL_1_1HalfedgeDS__decorator.html#a40e239711b1d6bb4d0667f1dcba6eb7a", null ],
      [ "create_center_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#aab9a84232293bb92215942724ff8f031", null ],
      [ "create_loop", "classCGAL_1_1HalfedgeDS__decorator.html#ac5be59d62d25988899e89a0f11af08ad", null ],
      [ "create_segment", "classCGAL_1_1HalfedgeDS__decorator.html#a4da7dbe7db457c36d72bf175cfa93fc0", null ],
      [ "erase_center_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#ab208edc47545010998b1f8e99743c969", null ],
      [ "erase_connected_component", "classCGAL_1_1HalfedgeDS__decorator.html#a2800be384e164bc1b37e1813a23268f9", null ],
      [ "erase_face", "classCGAL_1_1HalfedgeDS__decorator.html#a1a02e089ccc1090a9a2f964711816530", null ],
      [ "faces_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a5ecbcccfbb32c2ae254b2958b197e393", null ],
      [ "faces_erase", "classCGAL_1_1HalfedgeDS__decorator.html#ab346610310c2e2edc1ea263c84ea837f", null ],
      [ "faces_pop_back", "classCGAL_1_1HalfedgeDS__decorator.html#a5f356460eea97cfc8de888792e71b7aa", null ],
      [ "faces_pop_front", "classCGAL_1_1HalfedgeDS__decorator.html#afe0567091bfc31bc86411e4e17ef08d3", null ],
      [ "faces_push_back", "classCGAL_1_1HalfedgeDS__decorator.html#a17a2beec812aa907a51a35d5d945474a", null ],
      [ "fill_hole", "classCGAL_1_1HalfedgeDS__decorator.html#acb11be1cc4f3632d06ff1cecc15bd15d", null ],
      [ "fill_hole", "classCGAL_1_1HalfedgeDS__decorator.html#a579597e37ecf16055f4c06e21070f349", null ],
      [ "inside_out", "classCGAL_1_1HalfedgeDS__decorator.html#a0c86983214385afc13061180bf846038", null ],
      [ "is_valid", "classCGAL_1_1HalfedgeDS__decorator.html#a5a005d5e5e0a38229a15d726f57a440f", null ],
      [ "join_face", "classCGAL_1_1HalfedgeDS__decorator.html#a141fd44b925ab3dbc90be557bacb9c8f", null ],
      [ "join_loop", "classCGAL_1_1HalfedgeDS__decorator.html#a1b69fcdaeb8f93d0541025c3d2151746", null ],
      [ "join_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#a29ccc8f0bc7ccff0099ca930e0d80b0c", null ],
      [ "keep_largest_connected_components", "classCGAL_1_1HalfedgeDS__decorator.html#a22899f129fd20f3a48ea7b5398bab078", null ],
      [ "make_hole", "classCGAL_1_1HalfedgeDS__decorator.html#ab31c3730cc75826a4a6a558c7e89a527", null ],
      [ "normalized_border_is_valid", "classCGAL_1_1HalfedgeDS__decorator.html#a88ce03803651b438b445349a4a7e6e1e", null ],
      [ "split_face", "classCGAL_1_1HalfedgeDS__decorator.html#a5feab0c6d095ee98f4473e7d5682a731", null ],
      [ "split_loop", "classCGAL_1_1HalfedgeDS__decorator.html#a6bc0f54559aceafa2d662e3311f68f97", null ],
      [ "split_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#a767c212cf2f69d3e3ca4ca9f8c5fb017", null ],
      [ "vertices_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a92c0501ef7475f93813022fd24793acd", null ],
      [ "vertices_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a1f4717f24f8eaa82732adf3f66f5b87c", null ],
      [ "vertices_pop_back", "classCGAL_1_1HalfedgeDS__decorator.html#a73ec2c1fab067d83c8edf120c2420ecf", null ],
      [ "vertices_pop_front", "classCGAL_1_1HalfedgeDS__decorator.html#a00bd43f27f77e2df1cbc53f29f506c7a", null ],
      [ "vertices_push_back", "classCGAL_1_1HalfedgeDS__decorator.html#ae13a3f22784323ba96b680c3f0064b3a", null ]
    ] ],
    [ "HalfedgeDS_items_decorator", "classCGAL_1_1HalfedgeDS__items__decorator.html", [
      [ "difference_type", "classCGAL_1_1HalfedgeDS__items__decorator.html#a7e2484ac5d97b2506ecf981b5d8c0ef8", null ],
      [ "Face", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3b3ffdfffc3c61a7b88b7efbaf740a61", null ],
      [ "Face_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a2505b1cb009d5d0034458de8723ee8af", null ],
      [ "Face_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a46c7a0b8b0835023212c9245eab08a96", null ],
      [ "Halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#ad76498fd9532ab62fd12227949fc156b", null ],
      [ "Halfedge_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a03e1c1ec4d1a1f79ea6b8ca1a46ca8ed", null ],
      [ "Halfedge_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#af9830447eb711ee93de843e28742c425", null ],
      [ "HalfedgeDS", "classCGAL_1_1HalfedgeDS__items__decorator.html#a14b35bfdb0971ad0e92c3f2bdd19dee9", null ],
      [ "iterator_category", "classCGAL_1_1HalfedgeDS__items__decorator.html#a797fc62f63e7e6a3023ba600a51ce766", null ],
      [ "size_type", "classCGAL_1_1HalfedgeDS__items__decorator.html#abea61f3922eef7937f2cf85c0798a155", null ],
      [ "Supports_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a599349aac1c275f10abeee11f6f4433d", null ],
      [ "Supports_halfedge_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#ae9e58fab7ad971855be393fe9591b2a9", null ],
      [ "Supports_halfedge_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a327e44cad0b8a64c4ca7f0ba35de4b85", null ],
      [ "Supports_halfedge_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3a14d3bafbed1513363c6ff8dc747c9f", null ],
      [ "Supports_removal", "classCGAL_1_1HalfedgeDS__items__decorator.html#af2170cca6910cf85c810b0832ae0683e", null ],
      [ "Supports_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#abaf583a5196a7ae82e447cdecaac82ec", null ],
      [ "Vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3ec81f282874640587586934787bb85a", null ],
      [ "Vertex_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0f965d009888ebcca4a7bffc0af645dd", null ],
      [ "Vertex_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a745ebcc64c21d77ba3146d74e052484d", null ],
      [ "HalfedgeDS_items_decorator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4319e796df952b9353da1cd9e871c338", null ],
      [ "close_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a6b2e4086dce97da162b0442b705219ed", null ],
      [ "close_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3df8fab54043f40e2c5aa001f3862523", null ],
      [ "find_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0a7ded78b72adb3cd3611e4ebdb6af4c", null ],
      [ "find_prev_around_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#af4c7c86c8d5d6631cd46a35358fff151", null ],
      [ "flip_edge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4b28d2dca6278d77d5224e0337f65506", null ],
      [ "get_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#ae0302910dc6bf3d2553ce62739326c6b", null ],
      [ "get_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a77e81cf0cdee3c4d690459ca1f7df84e", null ],
      [ "get_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4c7eb053c8856216ff0a53077b4c831e", null ],
      [ "get_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4b518061b6472363a8220603d4d9e3b5", null ],
      [ "get_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a62abcaee8077e17541c805be3b31c81d", null ],
      [ "insert_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a1c32dcbd9c2a5510a8550011f356ccc0", null ],
      [ "insert_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a249b6ef7b32dc2b89bb778c769491cb8", null ],
      [ "remove_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#aaff553ceaac196e8bc48f78f8703bdf0", null ],
      [ "remove_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a65d5e26834c099fb8f40eb2acdc9d490", null ],
      [ "set_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#a9fd1e40d97140064377a41af44eff16a", null ],
      [ "set_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#af4192f0fc4ab8b35024b3edcf884dbac", null ],
      [ "set_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a5279715c8273086f8b834d6b1ce85ed4", null ],
      [ "set_face_in_face_loop", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0d904041cd7c4d2e56363fb263f2b842", null ],
      [ "set_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a1953707915df52d05cce6b9e3c030ff8", null ],
      [ "set_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a583ac40b281b656f2dd0ab32346b0a5c", null ],
      [ "set_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a98653ba2557dc75a31658f8dc7b394d3", null ],
      [ "set_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a99635e66eb9f9747afd1abaca5f899c4", null ],
      [ "set_vertex_in_vertex_loop", "classCGAL_1_1HalfedgeDS__items__decorator.html#a7e41872942eb1259f48d45ce4e2625f0", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/HalfedgeDS/group__PkgHalfedgeDS__Decorators.js <==
var group__PkgHalfedgeDS__Decorators =
[
    [ "CGAL::HalfedgeDS_const_decorator< HDS >", "classCGAL_1_1HalfedgeDS__const__decorator.html", [
      [ "HalfedgeDS_const_decorator", "classCGAL_1_1HalfedgeDS__const__decorator.html#ad5b6cdd3e8928c725e3c76b75503ca87", null ],
      [ "is_valid", "classCGAL_1_1HalfedgeDS__const__decorator.html#a20c407cf3b51a5405de75d6ecac54bb8", null ],
      [ "normalized_border_is_valid", "classCGAL_1_1HalfedgeDS__const__decorator.html#a2d34287e8e79a93a0c8aede41e24a33e", null ]
    ] ],
    [ "CGAL::HalfedgeDS_decorator< HDS >", "classCGAL_1_1HalfedgeDS__decorator.html", [
      [ "HalfedgeDS_decorator", "classCGAL_1_1HalfedgeDS__decorator.html#adbca9056aa23e29f8c5794577478aa12", null ],
      [ "add_face_to_border", "classCGAL_1_1HalfedgeDS__decorator.html#a03103d1282804931094481b8351e3416", null ],
      [ "add_face_to_border", "classCGAL_1_1HalfedgeDS__decorator.html#a40e239711b1d6bb4d0667f1dcba6eb7a", null ],
      [ "create_center_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#aab9a84232293bb92215942724ff8f031", null ],
      [ "create_loop", "classCGAL_1_1HalfedgeDS__decorator.html#ac5be59d62d25988899e89a0f11af08ad", null ],
      [ "create_segment", "classCGAL_1_1HalfedgeDS__decorator.html#a4da7dbe7db457c36d72bf175cfa93fc0", null ],
      [ "erase_center_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#ab208edc47545010998b1f8e99743c969", null ],
      [ "erase_connected_component", "classCGAL_1_1HalfedgeDS__decorator.html#a2800be384e164bc1b37e1813a23268f9", null ],
      [ "erase_face", "classCGAL_1_1HalfedgeDS__decorator.html#a1a02e089ccc1090a9a2f964711816530", null ],
      [ "faces_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a5ecbcccfbb32c2ae254b2958b197e393", null ],
      [ "faces_erase", "classCGAL_1_1HalfedgeDS__decorator.html#ab346610310c2e2edc1ea263c84ea837f", null ],
      [ "faces_pop_back", "classCGAL_1_1HalfedgeDS__decorator.html#a5f356460eea97cfc8de888792e71b7aa", null ],
      [ "faces_pop_front", "classCGAL_1_1HalfedgeDS__decorator.html#afe0567091bfc31bc86411e4e17ef08d3", null ],
      [ "faces_push_back", "classCGAL_1_1HalfedgeDS__decorator.html#a17a2beec812aa907a51a35d5d945474a", null ],
      [ "fill_hole", "classCGAL_1_1HalfedgeDS__decorator.html#acb11be1cc4f3632d06ff1cecc15bd15d", null ],
      [ "fill_hole", "classCGAL_1_1HalfedgeDS__decorator.html#a579597e37ecf16055f4c06e21070f349", null ],
      [ "inside_out", "classCGAL_1_1HalfedgeDS__decorator.html#a0c86983214385afc13061180bf846038", null ],
      [ "is_valid", "classCGAL_1_1HalfedgeDS__decorator.html#a5a005d5e5e0a38229a15d726f57a440f", null ],
      [ "join_face", "classCGAL_1_1HalfedgeDS__decorator.html#a141fd44b925ab3dbc90be557bacb9c8f", null ],
      [ "join_loop", "classCGAL_1_1HalfedgeDS__decorator.html#a1b69fcdaeb8f93d0541025c3d2151746", null ],
      [ "join_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#a29ccc8f0bc7ccff0099ca930e0d80b0c", null ],
      [ "keep_largest_connected_components", "classCGAL_1_1HalfedgeDS__decorator.html#a22899f129fd20f3a48ea7b5398bab078", null ],
      [ "make_hole", "classCGAL_1_1HalfedgeDS__decorator.html#ab31c3730cc75826a4a6a558c7e89a527", null ],
      [ "normalized_border_is_valid", "classCGAL_1_1HalfedgeDS__decorator.html#a88ce03803651b438b445349a4a7e6e1e", null ],
      [ "split_face", "classCGAL_1_1HalfedgeDS__decorator.html#a5feab0c6d095ee98f4473e7d5682a731", null ],
      [ "split_loop", "classCGAL_1_1HalfedgeDS__decorator.html#a6bc0f54559aceafa2d662e3311f68f97", null ],
      [ "split_vertex", "classCGAL_1_1HalfedgeDS__decorator.html#a767c212cf2f69d3e3ca4ca9f8c5fb017", null ],
      [ "vertices_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a1f4717f24f8eaa82732adf3f66f5b87c", null ],
      [ "vertices_erase", "classCGAL_1_1HalfedgeDS__decorator.html#a92c0501ef7475f93813022fd24793acd", null ],
      [ "vertices_pop_back", "classCGAL_1_1HalfedgeDS__decorator.html#a73ec2c1fab067d83c8edf120c2420ecf", null ],
      [ "vertices_pop_front", "classCGAL_1_1HalfedgeDS__decorator.html#a00bd43f27f77e2df1cbc53f29f506c7a", null ],
      [ "vertices_push_back", "classCGAL_1_1HalfedgeDS__decorator.html#ae13a3f22784323ba96b680c3f0064b3a", null ]
    ] ],
    [ "CGAL::HalfedgeDS_items_decorator< HDS >", "classCGAL_1_1HalfedgeDS__items__decorator.html", [
      [ "difference_type", "classCGAL_1_1HalfedgeDS__items__decorator.html#a7e2484ac5d97b2506ecf981b5d8c0ef8", null ],
      [ "Face", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3b3ffdfffc3c61a7b88b7efbaf740a61", null ],
      [ "Face_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a2505b1cb009d5d0034458de8723ee8af", null ],
      [ "Face_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a46c7a0b8b0835023212c9245eab08a96", null ],
      [ "Halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#ad76498fd9532ab62fd12227949fc156b", null ],
      [ "Halfedge_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a03e1c1ec4d1a1f79ea6b8ca1a46ca8ed", null ],
      [ "Halfedge_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#af9830447eb711ee93de843e28742c425", null ],
      [ "HalfedgeDS", "classCGAL_1_1HalfedgeDS__items__decorator.html#a14b35bfdb0971ad0e92c3f2bdd19dee9", null ],
      [ "iterator_category", "classCGAL_1_1HalfedgeDS__items__decorator.html#a797fc62f63e7e6a3023ba600a51ce766", null ],
      [ "size_type", "classCGAL_1_1HalfedgeDS__items__decorator.html#abea61f3922eef7937f2cf85c0798a155", null ],
      [ "Supports_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a599349aac1c275f10abeee11f6f4433d", null ],
      [ "Supports_halfedge_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#ae9e58fab7ad971855be393fe9591b2a9", null ],
      [ "Supports_halfedge_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a327e44cad0b8a64c4ca7f0ba35de4b85", null ],
      [ "Supports_halfedge_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3a14d3bafbed1513363c6ff8dc747c9f", null ],
      [ "Supports_removal", "classCGAL_1_1HalfedgeDS__items__decorator.html#af2170cca6910cf85c810b0832ae0683e", null ],
      [ "Supports_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#abaf583a5196a7ae82e447cdecaac82ec", null ],
      [ "Vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3ec81f282874640587586934787bb85a", null ],
      [ "Vertex_handle", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0f965d009888ebcca4a7bffc0af645dd", null ],
      [ "Vertex_iterator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a745ebcc64c21d77ba3146d74e052484d", null ],
      [ "HalfedgeDS_items_decorator", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4319e796df952b9353da1cd9e871c338", null ],
      [ "close_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a6b2e4086dce97da162b0442b705219ed", null ],
      [ "close_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a3df8fab54043f40e2c5aa001f3862523", null ],
      [ "find_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0a7ded78b72adb3cd3611e4ebdb6af4c", null ],
      [ "find_prev_around_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#af4c7c86c8d5d6631cd46a35358fff151", null ],
      [ "flip_edge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4b28d2dca6278d77d5224e0337f65506", null ],
      [ "get_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#ae0302910dc6bf3d2553ce62739326c6b", null ],
      [ "get_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a77e81cf0cdee3c4d690459ca1f7df84e", null ],
      [ "get_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4c7eb053c8856216ff0a53077b4c831e", null ],
      [ "get_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a4b518061b6472363a8220603d4d9e3b5", null ],
      [ "get_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a62abcaee8077e17541c805be3b31c81d", null ],
      [ "insert_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a1c32dcbd9c2a5510a8550011f356ccc0", null ],
      [ "insert_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a249b6ef7b32dc2b89bb778c769491cb8", null ],
      [ "remove_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#aaff553ceaac196e8bc48f78f8703bdf0", null ],
      [ "remove_tip", "classCGAL_1_1HalfedgeDS__items__decorator.html#a65d5e26834c099fb8f40eb2acdc9d490", null ],
      [ "set_face", "classCGAL_1_1HalfedgeDS__items__decorator.html#a9fd1e40d97140064377a41af44eff16a", null ],
      [ "set_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#af4192f0fc4ab8b35024b3edcf884dbac", null ],
      [ "set_face_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a5279715c8273086f8b834d6b1ce85ed4", null ],
      [ "set_face_in_face_loop", "classCGAL_1_1HalfedgeDS__items__decorator.html#a0d904041cd7c4d2e56363fb263f2b842", null ],
      [ "set_prev", "classCGAL_1_1HalfedgeDS__items__decorator.html#a1953707915df52d05cce6b9e3c030ff8", null ],
      [ "set_vertex", "classCGAL_1_1HalfedgeDS__items__decorator.html#a583ac40b281b656f2dd0ab32346b0a5c", null ],
      [ "set_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a99635e66eb9f9747afd1abaca5f899c4", null ],
      [ "set_vertex_halfedge", "classCGAL_1_1HalfedgeDS__items__decorator.html#a98653ba2557dc75a31658f8dc7b394d3", null ],
      [ "set_vertex_in_vertex_loop", "classCGAL_1_1HalfedgeDS__items__decorator.html#a7e41872942eb1259f48d45ce4e2625f0", null ]
    ] ]
];
